@@ -6,21 +6,22 @@ Base Extractor
 This module provides the base class for all derived extractors.
 
 """
-__author__ = 'Richard Smith'
-__date__ = '08 Jun 2021'
-__copyright__ = 'Copyright 2018 United Kingdom Research and Innovation'
-__license__ = 'BSD - see LICENSE file in top-level package directory'
-__contact__ = 'richard.d.smith@stfc.ac.uk'
+__author__ = "Richard Smith"
+__date__ = "08 Jun 2021"
+__copyright__ = "Copyright 2018 United Kingdom Research and Innovation"
+__license__ = "BSD - see LICENSE file in top-level package directory"
+__contact__ = "richard.d.smith@stfc.ac.uk"
 
-from abc import ABC, abstractmethod
-from .utils import load_plugins
-from .handler_picker import HandlerPicker
-from .item_describer import ItemDescriptions, ItemDescription
-from asset_scanner.types.source_media import StorageType
 import re
-
+from abc import ABC, abstractmethod
 from typing import List
 
+from asset_scanner.types.source_media import StorageType
+
+from .handler_picker import HandlerPicker
+from .item_describer import ItemDescription, ItemDescriptions
+from .utils import load_plugins
+
 
 class BaseExtractor(ABC):
     """
@@ -29,17 +30,23 @@ class BaseExtractor(ABC):
     Attributes:
 
         PROCESSOR_ENTRY_POINT:
-            Defines the entry point to look for in the setup.py for the downstream
-            package. This is used by the ``asset_scanner`` command to load the extractor
-            if the extractor is not specifically defined in the the configuration file.
+            Defines the entry point to look for in the setup.py for the
+            downstream package. This is used by the ``asset_scanner`` command
+            to load the extractor if the extractor is not specifically defined
+            in the the configuration file.
     """
+
     PROCESSOR_ENTRY_POINT = None
 
     def __init__(self, conf: dict):
         self.conf = conf
         self.processors = self.load_processors()
         self.output_plugins = self.load_output_plugins()
-        self.item_descriptions = ItemDescriptions(conf['item_descriptions']['root_directory']) if 'item_descriptions' in conf else None
+        self.item_descriptions = (
+            ItemDescriptions(conf["item_descriptions"]["root_directory"])
+            if "item_descriptions" in conf
+            else None
+        )
 
         self.load_processors()
 
@@ -61,7 +68,9 @@ class BaseExtractor(ABC):
 
         return label
 
-    def get_categories(self, filepath: str, source_media: StorageType, description: ItemDescription) -> List:
+    def get_categories(
+        self, filepath: str, source_media: StorageType, description: ItemDescription
+    ) -> List:
         """
         Get asset category labels
 
@@ -78,19 +87,27 @@ class BaseExtractor(ABC):
             if label:
                 categories.add(label)
 
-        return list(categories) or ['data']
+        return list(categories) or ["data"]
 
     def load_processors(self, entrypoint: str = None) -> HandlerPicker:
         return HandlerPicker(entrypoint or self.PROCESSOR_ENTRY_POINT)
 
     def load_output_plugins(self) -> List:
-        return load_plugins(self.conf, 'asset_scanner.output_plugins', 'outputs')
+        return load_plugins(self.conf, "asset_scanner.output_plugins", "outputs")
 
     @abstractmethod
-    def process_file(self, filepath: str, source_media: StorageType = StorageType.POSIX, **kwargs) -> None:
+    def process_file(
+        self, filepath: str, source_media: StorageType = StorageType.POSIX, **kwargs
+    ) -> None:
         pass
 
-    def output(self, filepath: str, source_media: StorageType, data: dict, namespace: str = None) -> None:
+    def output(
+        self,
+        filepath: str,
+        source_media: StorageType,
+        data: dict,
+        namespace: str = None,
+    ) -> None:
         for backend in self.output_plugins:
             if not backend.namespace or backend.namespace == namespace:
                 backend.export(data)
