@@ -3,7 +3,8 @@
 Intake Input
 -----------------
 
-Uses an `Intake catalog <https://intake.readthedocs.io/>`_ as a source for file objects.
+Uses an `Intake catalog <https://intake.readthedocs.io/>`_
+as a source for file objects.
 
 **Plugin name:** ``intake_esm``
 
@@ -18,13 +19,19 @@ Uses an `Intake catalog <https://intake.readthedocs.io/>`_ as a source for file
       - ``REQUIRED`` The URI of a path or URL to an ESM collection JSON file.
     * - ``object_path_attr``
       - ``string``
-      - ``REQUIRED`` The column header which contains the URI to the file object.
+      - ``REQUIRED`` The column header which contains the URI to
+        the file object.
     * - ``catalog_kwargs``
       - ``dict``
-      - Optional kwargs to pass to `intake.open_esm_datastore <https://intake-esm.readthedocs.io/en/latest/api.html#intake_esm.core.esm_datastore>`_
+      - Optional kwargs to pass to
+        `intake.open_esm_datastore
+        <https://intake-esm.readthedocs.io/en/latest
+        /api.html#intake_esm.core.esm_datastore>`_
     * - ``search_kwargs``
       - ``dict``
-      - Optional kwargs to pass to `esm_datastore.search <https://intake-esm.readthedocs.io/en/latest/api.html#intake_esm.core.esm_datastore.search>`_
+      - Optional kwargs to pass to `esm_datastore.search
+        <https://intake-esm.readthedocs.io/en/latest
+        /api.html#intake_esm.core.esm_datastore.search>`_
 
 
 Example Configuration:
@@ -35,32 +42,29 @@ Example Configuration:
               uri: test_directory
 
 """
-__author__ = 'Richard Smith'
-__date__ = '23 Sep 2021'
-__copyright__ = 'Copyright 2018 United Kingdom Research and Innovation'
-__license__ = 'BSD - see LICENSE file in top-level package directory'
-__contact__ = 'richard.d.smith@stfc.ac.uk'
+__author__ = "Richard Smith"
+__date__ = "23 Sep 2021"
+__copyright__ = "Copyright 2018 United Kingdom Research and Innovation"
+__license__ = "BSD - see LICENSE file in top-level package directory"
+__contact__ = "richard.d.smith@stfc.ac.uk"
 
-# Package imports
-from .base import BaseInputPlugin
-
-# Framework imports
-from asset_scanner.types.source_media import StorageType
+# Python imports
+import logging
+from datetime import datetime
+from typing import TYPE_CHECKING
+from urllib.parse import urlparse
 
 # Thirdparty imports
 import intake
 
+# Framework imports
+from asset_scanner.types.source_media import StorageType
 
-# Python imports
-from datetime import datetime
-import logging
-from urllib.parse import urlparse
-from typing import Optional, Tuple
-
+# Package imports
+from .base import BaseInputPlugin
 
 logger = logging.getLogger(__name__)
 
-from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
     from asset_scanner.core import BaseExtractor
@@ -73,27 +77,27 @@ class IntakeESMInputPlugin(BaseInputPlugin):
 
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
-        self.uri = kwargs['uri']
-        self.object_attr = kwargs['object_path_attr']
+        self.uri = kwargs["uri"]
+        self.object_attr = kwargs["object_path_attr"]
 
-        self.intake_kwargs = kwargs.get('catalog_kwargs', {})
-        self.search_kwargs = kwargs.get('search_kwargs')
+        self.intake_kwargs = kwargs.get("catalog_kwargs", {})
+        self.search_kwargs = kwargs.get("search_kwargs")
 
     def open_catalog(self):
         """Open the ESM catalog and perform a search, if required."""
-        logger.info('Opening catalog')
+        logger.info("Opening catalog")
         catalog = intake.open_esm_datastore(self.uri, **self.intake_kwargs)
 
         if self.search_kwargs:
             catalog = catalog.search(**self.search_kwargs)
 
-        logger.info(f'Found {len(catalog.df)} items')
+        logger.info(f"Found {len(catalog.df)} items")
         return catalog
 
-    def run(self, extractor: 'BaseExtractor'):
+    def run(self, extractor: "BaseExtractor"):
         total_files = 0
         start = datetime.now()
-        
+
         catalog = self.open_catalog()
 
         for index, row in catalog.df.iterrows():
@@ -108,11 +112,11 @@ class IntakeESMInputPlugin(BaseInputPlugin):
 
             if self.should_process(filepath, media_type):
                 extractor.process_file(filepath, media_type)
-                logger.debug(f'Input processing: {filepath}')
+                logger.debug(f"Input processing: {filepath}")
             else:
-                logger.debug(f'Input skipping: {filepath}')
+                logger.debug(f"Input skipping: {filepath}")
 
             total_files += 1
 
         end = datetime.now()
-        print(f'Processed {total_files} files from {self.uri} in {end-start}')
\ No newline at end of file
+        print(f"Processed {total_files} files from {self.uri} in {end-start}")
